@@ -61,7 +61,8 @@ xena_default_hosts <- function() {
     "https://pcawg.xenahubs.net",
     "https://atacseq.xenahubs.net",
     "https://singlecellnew.xenahubs.net",
-    "https://kidsfirst.xenahubs.net"
+    "https://kidsfirst.xenahubs.net",
+    "https://tdi.xenahubs.net"
   )
 }
 
@@ -76,7 +77,8 @@ xena_default_hosts <- function() {
   "pcawgHub",
   "atacseqHub",
   "singlecellHub",
-  "kidsfirstHub"
+  "kidsfirstHub",
+  "tdiHub"
 )
 
 names(.xena_hosts) <- xena_default_hosts()
@@ -130,7 +132,8 @@ XenaHub <- function(hosts = xena_default_hosts(),
                       "pcawgHub",
                       "atacseqHub",
                       "singlecellHub",
-                      "kidsfirstHub"
+                      "kidsfirstHub",
+                      "tdiHub"
                     )) {
   stopifnot(
     is.character(hosts),
